@@ -18,8 +18,19 @@ alpha = cmath.exp(1j * ((2 / 3) * cmath.pi))
 alpha2 = cmath.exp(1j * ((-2 / 3) * cmath.pi))
 
 
-def convert_symm_to_abc(pos_pu:complex, neg_pu:complex, zero_pu:complex=0) -> Tuple[complex, complex, complex]:
-    a_pu = pos_pu + neg_pu + zero_pu
-    b_pu = alpha2 * pos_pu + alpha * neg_pu + zero_pu
-    c_pu = alpha * pos_pu + alpha2 * neg_pu + zero_pu
-    return a_pu, b_pu, c_pu
\ No newline at end of file
+def convert_symm_to_abc(pos:complex, neg:complex, zero:complex=0) -> Tuple[complex, complex, complex]:
+    """
+    |  Convert symmetrical components (positive, negative, zero sequence) to phase components (abc axis)
+    :param pos: Positive sequence component
+    :param neg: Negative sequence component
+    :param zero: Zero sequence component
+
+    Output:
+    :param a: Phase A component
+    :param b: Phase B component
+    :param c: Phase C component
+    """
+    a = pos + neg + zero
+    b = alpha2 * pos + alpha * neg + zero
+    c = alpha * pos + alpha2 * neg + zero
+    return a, b, c
\ No newline at end of file
